Graphical User Interface
========================

This package provides a simple graphical user interface to enable quick calculations of x-ray transmission and absorption through materials.
This GUI makes use of `bokeh <https://bokeh.pydata.org>`_.

To run it locally use the following command::

    bokeh serve --show <roengten_directory>/gui

